=====
Usage
=====

After following :ref:`installation:Installation` instructions,
to use GodSpeed in a project::

    >>> import godspeed

.. note::
   See :ref:`package docs <godspeed:godspeed package>` section for documentation.
